{ pkgs, stdenv, lib, buildLinux, ... } @ args:

with lib;
let
  kernelVersion = "5.18.16";
  patches = pkgs.fetchFromGitHub {
    owner = "Redecorating";
    repo = "linux-t2-arch";
    rev = "2222222222222222222222222222222222222222222222222222";
    sha256 = "sha256-/gxnq0Gz/N1u6m/oes7a6NlJQ7CoMwnFNxztQhDt46Q=";
  };
in
buildLinux (args // rec {
  version = "${kernelVersion}-mbp";
  modDirVersion = kernelVersion;
  extraMeta.branch = versions.majorMinor version;

  src = pkgs.fetchurl {
    url = "mirror://kernel/linux/kernel/v5.x/linux-${kernelVersion}.tar.xz";
    sha256 = "sha256-8fWGJR5j3hTIbl+VuWvrFaBDTx5uId94jRI1ZK8NEc4=";
  };

  kernelPatches = [
        #rec { name = "0001-arch-additions"; patch = "${patches}/${name}.patch"; }
        #rec { name = "1001-Put-apple-bce-and-apple-ibridge-in-drivers-staging"; patch = "${patches}/${name}.patch"; }
        #rec { name = "1002-add-modalias-to-apple-bce"; patch = "${patches}/${name}.patch"; }
        rec { name = "2001-fix-acpica-for-zero-arguments-acpi-calls"; patch = "${patches}/${name}.patch"; }
        rec { name = "2002-efi-Correct-Macmini-capitalisation-in-uefi-cert-quir"; patch = "${patches}/${name}.patch"; }
        rec { name = "3001-applesmc-convert-static-structures-to-drvdata"; patch = "${patches}/${name}.patch"; }
        rec { name = "3002-applesmc-make-io-port-base-addr-dynamic"; patch = "${patches}/${name}.patch"; }
        rec { name = "3003-applesmc-switch-to-acpi_device-from-platform"; patch = "${patches}/${name}.patch"; }
        rec { name = "3004-applesmc-key-interface-wrappers"; patch = "${patches}/${name}.patch"; }
        rec { name = "3005-applesmc-basic-mmio-interface-implementation"; patch = "${patches}/${name}.patch"; }
        rec { name = "3006-applesmc-fan-support-on-T2-Macs"; patch = "${patches}/${name}.patch"; }
        rec { name = "3007-applesmc-Add-iMacPro-to-applesmc_whitelist"; patch = "${patches}/${name}.patch"; }
        rec { name = "4001-Input-bcm5974-Add-support-for-the-T2-Macs"; patch = "${patches}/${name}.patch"; }
        rec { name = "5001-Fix-for-touchbar"; patch = "${patches}/${name}.patch"; }
        rec { name = "7001-drm-i915-fbdev-Discard-BIOS-framebuffers-exceeding-h"; patch = "${patches}/${name}.patch"; }
        rec { name = "8001-asahilinux-wifi-patchset"; patch = "${patches}/${name}.patch"; }
        rec { name = "8002-asahilinux-hci_bcm4377-patchset"; patch = "${patches}/${name}.patch"; }
      ];
} // (args.argsOverride or { }))
